pub enum CreateUserError {
DirectoryServiceAuthenticationFailed(String),
DirectoryUnavailable(String),
InvalidParameter(String),
InvalidPassword(String),
NameAvailability(String),
OrganizationNotFound(String),
OrganizationState(String),
ReservedName(String),
UnsupportedOperation(String),
}Expand description
Errors returned by CreateUser
Variants
DirectoryServiceAuthenticationFailed(String)
The directory service doesn't recognize the credentials supplied by WorkMail.
The directory on which you are trying to perform operations isn't available.
InvalidParameter(String)
One or more of the input parameters don't match the service's restrictions.
InvalidPassword(String)
The supplied password doesn't match the minimum security constraints, such as length or use of special characters.
NameAvailability(String)
The user, group, or resource name isn't unique in Amazon WorkMail.
OrganizationNotFound(String)
An operation received a valid organization identifier that either doesn't belong or exist in the system.
OrganizationState(String)
The organization must have a valid state (Active or Synchronizing) to perform certain operations on the organization or its members.
ReservedName(String)
This user, group, or resource name is not allowed in Amazon WorkMail.
UnsupportedOperation(String)
You can't perform a write operation against a read-only directory.
Implementations
Sourceimpl CreateUserError
impl CreateUserError
pub fn from_response(res: BufferedHttpResponse) -> RusotoError<CreateUserError>