pub enum RegisterToWorkMailError {
DirectoryServiceAuthenticationFailed(String),
DirectoryUnavailable(String),
EmailAddressInUse(String),
EntityAlreadyRegistered(String),
EntityNotFound(String),
EntityState(String),
InvalidParameter(String),
MailDomainNotFound(String),
MailDomainState(String),
OrganizationNotFound(String),
OrganizationState(String),
}Expand description
Errors returned by RegisterToWorkMail
Variants
DirectoryServiceAuthenticationFailed(String)
The directory service doesn't recognize the credentials supplied by WorkMail.
The directory on which you are trying to perform operations isn't available.
EmailAddressInUse(String)
The email address that you're trying to assign is already created for a different user, group, or resource.
EntityAlreadyRegistered(String)
The user, group, or resource that you're trying to register is already registered.
EntityNotFound(String)
The identifier supplied for the user, group, or resource does not exist in your organization.
EntityState(String)
You are performing an operation on a user, group, or resource that isn't in the expected state, such as trying to delete an active user.
InvalidParameter(String)
One or more of the input parameters don't match the service's restrictions.
MailDomainNotFound(String)
For an email or alias to be created in Amazon WorkMail, the included domain must be defined in the organization.
MailDomainState(String)
After a domain has been added to the organization, it must be verified. The domain is not yet verified.
OrganizationNotFound(String)
An operation received a valid organization identifier that either doesn't belong or exist in the system.
OrganizationState(String)
The organization must have a valid state (Active or Synchronizing) to perform certain operations on the organization or its members.
Implementations
Sourceimpl RegisterToWorkMailError
impl RegisterToWorkMailError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<RegisterToWorkMailError>